package io.dekorate.project;

import io.dekorate.deps.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ProjectBuilder extends ProjectFluentImpl<ProjectBuilder> implements VisitableBuilder<Project,ProjectBuilder>{

    ProjectFluent<?> fluent;
    Boolean validationEnabled;

    public ProjectBuilder(){
            this(true);
    }
    public ProjectBuilder(Boolean validationEnabled){
            this(new Project(), validationEnabled);
    }
    public ProjectBuilder(ProjectFluent<?> fluent){
            this(fluent, true);
    }
    public ProjectBuilder(ProjectFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new Project(), validationEnabled);
    }
    public ProjectBuilder(ProjectFluent<?> fluent,Project instance){
            this(fluent, instance, true);
    }
    public ProjectBuilder(ProjectFluent<?> fluent,Project instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withRoot(instance.getRoot()); 
            fluent.withDekorateInputDir(instance.getDekorateInputDir()); 
            fluent.withDekorateOutputDir(instance.getDekorateOutputDir()); 
            fluent.withBuildInfo(instance.getBuildInfo()); 
            fluent.withScmInfo(instance.getScmInfo()); 
            this.validationEnabled = validationEnabled; 
    }
    public ProjectBuilder(Project instance){
            this(instance,true);
    }
    public ProjectBuilder(Project instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withRoot(instance.getRoot()); 
            this.withDekorateInputDir(instance.getDekorateInputDir()); 
            this.withDekorateOutputDir(instance.getDekorateOutputDir()); 
            this.withBuildInfo(instance.getBuildInfo()); 
            this.withScmInfo(instance.getScmInfo()); 
            this.validationEnabled = validationEnabled; 
    }

    public io.dekorate.project.EditableProject build(){
            EditableProject buildable = new EditableProject(fluent.getRoot(),fluent.getBuildInfo(),fluent.getScmInfo());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ProjectBuilder that = (ProjectBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
